@@ -1,5 +1,5 @@
 package Statocles;
-our $VERSION = '0.094';
+our $VERSION = '0.095';
 # ABSTRACT: A static site generator
 
 use Statocles::Base 'Class';
@@ -171,7 +171,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.094
+version 0.095
 
 =head1 SYNOPSIS
 
@@ -297,12 +297,16 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords David Farrell djerius Ed J Ferenc Erki Joel Berger Kent Fredric Konrad Bucheli Mohammad S Anwar perlancar (@netbook-zenbook-ux305) Roy Storey tadegenban Vladimir Lettiev William Lindley Wojtek Bażant
+=for stopwords Cthulhux David Farrell djerius Ed J Ferenc Erki Joel Berger Kent Fredric Konrad Bucheli Mohammad S Anwar perlancar (@netbook-zenbook-ux305) Roy Storey tadegenban Vladimir Lettiev William Lindley Wojtek Bażant
 
 =over 4
 
 =item *
 
+Cthulhux <git@tuxproject.de>
+
+=item *
+
 David Farrell <davidnmfarrell@gmail.com>
 
 =item *
