@@ -1,5 +1,5 @@
 package Statocles::Plugin::HTMLLint;
-our $VERSION = '0.094';
+our $VERSION = '0.095';
 # ABSTRACT: Check HTML for common errors and issues
 
 use Statocles::Base 'Class';
@@ -9,6 +9,19 @@ BEGIN {
         or die "Error loading Statocles::Plugin::HTMLLint. To use this plugin, install HTML::Lint::Pluggable";
 };
 
+#pod =attr fatal
+#pod
+#pod If set to true, and there are any linting errors, the plugin will also call
+#pod C<die()> after printing the problems. Defaults to false.
+#pod
+#pod =cut
+
+has fatal => (
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+);
+
 #pod =attr plugins
 #pod
 #pod The L<HTML::Lint::Pluggable> plugins to use. Defaults to a generic set of
@@ -53,6 +66,8 @@ sub check_pages {
         for my $error ( @errors ) {
             $event->emitter->log->warn( "-" . $error->as_string );
         }
+
+        die 'Linting failed!' if $self->fatal;
     }
 }
 
@@ -81,7 +96,7 @@ Statocles::Plugin::HTMLLint - Check HTML for common errors and issues
 
 =head1 VERSION
 
-version 0.094
+version 0.095
 
 =head1 SYNOPSIS
 
@@ -96,10 +111,16 @@ version 0.094
 =head1 DESCRIPTION
 
 This plugin checks all of the HTML to ensure it's correct and complete. If something
-is missing, this plugin will write a warning to the screen.
+is missing, this plugin will write a warning to the screen. If fatal is set to true,
+it will also call C<die()> afterwards.
 
 =head1 ATTRIBUTES
 
+=head2 fatal
+
+If set to true, and there are any linting errors, the plugin will also call
+C<die()> after printing the problems. Defaults to false.
+
 =head2 plugins
 
 The L<HTML::Lint::Pluggable> plugins to use. Defaults to a generic set of
